@@ -6,6 +6,7 @@ import StringIO
 import tempfile
 import os
 import urllib
+import logging
 
 from jss.connection import JssClient
 
@@ -53,11 +54,14 @@ class Storage(driver.Base):
     
     @lru.set
     def put_content(self, path, content):
+        print path
         path = self._init_path(path)
+        print path
         try:
             object_instance = self._jss.bucket(self._bucket).object(path)
             object_instance.upload_flow(None, content)
         except Exception as e:
+            print e
             raise e
         return path
 
